@@ -24,9 +24,13 @@
 #include <gtk/gtk.h>
 #include <pango/pango-font.h>
 
+G_BEGIN_DECLS
+
 gchar *get_style (GtkWidget *widget, const gchar *name, const gchar *state);
 GdkGC *get_style_gc (GtkWidget *widget, const gchar *state, const gchar *style);
 PangoFontDescription *get_font_desc (GtkWidget *widget);
 PangoContext *pango_get_context (GtkWidget *widget);
 
+G_END_DECLS
+
 #endif
