@@ -1,4 +1,4 @@
-/* $Id: xfce_scaled_image.c,v 1.5 2004/11/02 13:16:58 jasper Exp $
+/* $Id$
  * 
  * Copyright 2004 Jasper Huijsmans (jasper@xfce.org)
  *
@@ -65,7 +65,8 @@ xfce_scaled_image_get_type (void)
 	    NULL,		/* class_data */
 	    sizeof (XfceScaledImage),
 	    0,			/* n_preallocs */
-	    (GInstanceInitFunc) xfce_scaled_image_init
+	    (GInstanceInitFunc) xfce_scaled_image_init,
+	    NULL		/* value_table */
 	};
 
 	scaled_image_type =
